summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2016-12-30 08:38:19 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2016-12-30 08:41:07 -0600
commitdbf3e10487e1472cc79c48567d6486314e384540 (patch)
tree11ae6d88e17aa1ed084fa8cdc3821b95e27278c1
parent237b11b5730e9d82f66d300116198bbee52c7084 (diff)
downloadlibpng-dbf3e10487e1472cc79c48567d6486314e384540.tar.gz
[libpng15] Bump version to 1.5.29beta01
-rw-r--r--ANNOUNCE52
-rw-r--r--CHANGES2
-rw-r--r--CMakeLists.txt4
-rw-r--r--LICENSE6
-rw-r--r--README2
-rwxr-xr-xconfigure24
-rw-r--r--configure.ac6
-rw-r--r--contrib/libtests/pngvalid.c2
-rw-r--r--libpng-manual.txt6
-rw-r--r--libpng.318
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c14
-rw-r--r--png.h28
-rw-r--r--pngconf.h2
-rw-r--r--pngtest.c2
-rw-r--r--projects/vstudio/README.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt10
-rw-r--r--scripts/def.c2
-rwxr-xr-xscripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.cegcc2
-rw-r--r--scripts/makefile.linux2
-rw-r--r--scripts/makefile.msys2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/pnglibconf.h.prebuilt4
-rw-r--r--scripts/symbols.def2
30 files changed, 95 insertions, 117 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 510d1d38d..e8590db73 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,56 +1,32 @@
-Libpng 1.5.28 - December 29, 2016
+Libpng 1.5.29beta01 - December 30, 2016
-This is a public release of libpng, intended for use in production codes.
+This is not intended to be a public release. It will be replaced
+within a few weeks by a public version or by another test version.
Files available for download:
Source files with LF line endings (for Unix/Linux) and with a
"configure" script
- libpng-1.5.28.tar.xz (LZMA-compressed, recommended)
- libpng-1.5.28.tar.gz
+ 1.5.29beta01.tar.xz (LZMA-compressed, recommended)
+ 1.5.29beta01.tar.gz
Source files with CRLF line endings (for Windows), without the
"configure" script
- lpng1528.7z (LZMA-compressed, recommended)
- lpng1528.zip
+ lp1529b01.7z (LZMA-compressed, recommended)
+ lp1529b01.zip
Other information:
- libpng-1.5.28-README.txt
- libpng-1.5.28-LICENSE.txt
- libpng-1.5.28-*.asc (armored detached GPG signatures)
-
-Changes since the last public release (1.5.27):
-
- Merged with current libpng16 gregbook, pngvalid.c, pngtest.c, pngminim,
- pngminus
- Added "Common linking failures" section to INSTALL.
- Fixed undefined behavior in png_push_save_buffer(). Do not call
- memcpy() with a null source, even if count is zero (Leon Scroggins III).
- Merge contrib/pngminim/*/makefile with libpng-1.6.24
- Minor editing of INSTALL, (whitespace, added copyright line)
- Removed the use of a macro containing the pre-processor 'defined'
- operator. It is unclear whether this is valid; a macro that
- "generates" 'defined' is not permitted, but the use of the word
- "generates" within the C90 standard seems to imply more than simple
- substitution of an expression itself containing a well-formed defined
- operation.
- Previously the pngtrans.c code always resulted in an unsigned arithmetic
- overflow. This is well defined but produces errors from clang with the
- option to detect unsigned overflow. As the expression only gets
- evaluated once per row in this version of libpng it is easier just
- to rewrite it.
- The previous version of png.c produced a signed overflow as a result of
- both the "& 0xffff" on the most significant bits of a negative argument;
- this converted (-1) into 65535 which resulted in a subsequent overflow.
- Since signed overflow is undefined in C90 the code has been modified to
- correctly calculate a signed result. This requires changing the 'hi'
- result parameter to a signed value.
- Fixed a potential null pointer dereference in png_set_text_2() (bug report
- and patch by Patrick Keshishian).
+ 1.5.29beta01-README.txt
+ 1.5.29beta01-LICENSE.txt
+ libpng-1.5.29beta01-*.asc (armored detached GPG signatures)
+
+Changes since the last public release (1.5.28):
+
+version 1.5.29beta01 [December 30, 2016]
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/CHANGES b/CHANGES
index dfb660a8b..b0f94f3d0 100644
--- a/CHANGES
+++ b/CHANGES
@@ -4531,6 +4531,8 @@ version 1.5.28 [December 29, 2016]
Fixed a potential null pointer dereference in png_set_text_2() (bug report
and patch by Patrick Keshishian).
+version 1.5.29beta01 [December 30, 2016]
+
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
https://lists.sourceforge.net/lists/listinfo/png-mng-implement
diff --git a/CMakeLists.txt b/CMakeLists.txt
index ea9169dcc..b0ecb12e1 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -35,7 +35,7 @@ enable_testing()
set(PNGLIB_MAJOR 1)
set(PNGLIB_MINOR 5)
-set(PNGLIB_RELEASE 28)
+set(PNGLIB_RELEASE 29)
set(PNGLIB_NAME libpng${PNGLIB_MAJOR}${PNGLIB_MINOR})
set(PNGLIB_VERSION ${PNGLIB_MAJOR}.${PNGLIB_MINOR}.${PNGLIB_RELEASE})
@@ -535,7 +535,7 @@ endif(NOT WIN32 OR CYGWIN OR MINGW)
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(png PROPERTIES
-# VERSION 15.${PNGLIB_RELEASE}.1.5.28
+# VERSION 15.${PNGLIB_RELEASE}.1.5.29beta01
VERSION 15.${PNGLIB_RELEASE}.0
SOVERSION 15
CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index 8fe915182..d78cb5c45 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,8 +10,8 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000, through 1.5.28, December 29, 2016, are
-Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
+libpng versions 1.0.7, July 1, 2000, through 1.5.29beta01, December 30, 2016, are
+Copyright (c) 2000-2002, 2004, 2006-2017 Glenn Randers-Pehrson, are
derived from libpng-1.0.6, and are distributed according to the same
disclaimer and license as libpng-1.0.6 with the following individuals
added to the list of Contributing Authors:
@@ -119,4 +119,4 @@ any encryption software. See the EAR, paragraphs 734.3(b)(3) and
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-December 29, 2016
+December 30, 2016
diff --git a/README b/README
index ca6c6bfd6..8c419be4b 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.28 - December 29, 2016 (shared library 15.0)
+README for libpng version 1.5.29beta01 - December 30, 2016 (shared library 15.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/configure b/configure
index 04de3623b..45df056ef 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
#! /bin/sh
# Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for libpng 1.5.28.
+# Generated by GNU Autoconf 2.69 for libpng 1.5.29beta01.
#
# Report bugs to <png-mng-implement@lists.sourceforge.net>.
#
@@ -590,8 +590,8 @@ MAKEFLAGS=
# Identity of this package.
PACKAGE_NAME='libpng'
PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.5.28'
-PACKAGE_STRING='libpng 1.5.28'
+PACKAGE_VERSION='1.5.29beta01'
+PACKAGE_STRING='libpng 1.5.29beta01'
PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
PACKAGE_URL=''
@@ -1354,7 +1354,7 @@ if test "$ac_init_help" = "long"; then
# Omit some internal or obsolete options to make the list less imposing.
# This message is too long to be a string in the A/UX 3.1 sh.
cat <<_ACEOF
-\`configure' configures libpng 1.5.28 to adapt to many kinds of systems.
+\`configure' configures libpng 1.5.29beta01 to adapt to many kinds of systems.
Usage: $0 [OPTION]... [VAR=VALUE]...
@@ -1424,7 +1424,7 @@ fi
if test -n "$ac_init_help"; then
case $ac_init_help in
- short | recursive ) echo "Configuration of libpng 1.5.28:";;
+ short | recursive ) echo "Configuration of libpng 1.5.29beta01:";;
esac
cat <<\_ACEOF
@@ -1579,7 +1579,7 @@ fi
test -n "$ac_init_help" && exit $ac_status
if $ac_init_version; then
cat <<\_ACEOF
-libpng configure 1.5.28
+libpng configure 1.5.29beta01
generated by GNU Autoconf 2.69
Copyright (C) 2012 Free Software Foundation, Inc.
@@ -2002,7 +2002,7 @@ cat >config.log <<_ACEOF
This file contains any messages produced by compilers while
running configure, to aid debugging if configure makes a mistake.
-It was created by libpng $as_me 1.5.28, which was
+It was created by libpng $as_me 1.5.29beta01, which was
generated by GNU Autoconf 2.69. Invocation command line was
$ $0 $@
@@ -2865,7 +2865,7 @@ fi
# Define the identity of the package.
PACKAGE='libpng'
- VERSION='1.5.28'
+ VERSION='1.5.29beta01'
cat >>confdefs.h <<_ACEOF
@@ -2982,10 +2982,10 @@ fi
-PNGLIB_VERSION=1.5.28
+PNGLIB_VERSION=1.5.29beta01
PNGLIB_MAJOR=1
PNGLIB_MINOR=5
-PNGLIB_RELEASE=28
+PNGLIB_RELEASE=29
@@ -14124,7 +14124,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
# report actual input values of CONFIG_FILES etc. instead of their
# values after options handling.
ac_log="
-This file was extended by libpng $as_me 1.5.28, which was
+This file was extended by libpng $as_me 1.5.29beta01, which was
generated by GNU Autoconf 2.69. Invocation command line was
CONFIG_FILES = $CONFIG_FILES
@@ -14190,7 +14190,7 @@ _ACEOF
cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
ac_cs_version="\\
-libpng config.status 1.5.28
+libpng config.status 1.5.29beta01
configured by $0, generated by GNU Autoconf 2.69,
with options \\"\$ac_cs_config\\"
diff --git a/configure.ac b/configure.ac
index 24302aa23..94c1ab7cd 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,15 +18,15 @@ AC_PREREQ(2.59)
dnl Version number stuff here:
-AC_INIT([libpng], [1.5.28], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.5.29beta01], [png-mng-implement@lists.sourceforge.net])
AM_INIT_AUTOMAKE([1.13 serial-tests subdir-objects])
dnl stop configure from automagically running automake
AM_MAINTAINER_MODE
-PNGLIB_VERSION=1.5.28
+PNGLIB_VERSION=1.5.29beta01
PNGLIB_MAJOR=1
PNGLIB_MINOR=5
-PNGLIB_RELEASE=28
+PNGLIB_RELEASE=29
dnl End of version number stuff
diff --git a/contrib/libtests/pngvalid.c b/contrib/libtests/pngvalid.c
index 499801b30..b0b75b94b 100644
--- a/contrib/libtests/pngvalid.c
+++ b/contrib/libtests/pngvalid.c
@@ -1,7 +1,7 @@
/* pngvalid.c - validate libpng by constructing then reading png files.
*
- * Last changed in libpng 1.6.27 [December 29, 2016]
+ * Last changed in libpng 1.6.27 [(PENDING RELEASE)]
* Copyright (c) 2014-2016 John Cunningham Bowler
*
* This code is released under the libpng license.
diff --git a/libpng-manual.txt b/libpng-manual.txt
index fecfff64e..df6e67c30 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
Libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.28 - December 29, 2016
+ libpng version 1.5.29beta01 - December 30, 2016
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ Libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.28 - December 29, 2016
+ libpng versions 0.97, January 1998, through 1.5.29beta01 - December 30, 2016
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -4516,7 +4516,7 @@ Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.28 are Y2K compliant. It is my belief that earlier
+upward through 1.5.29beta01 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has two year fields. One is a 2-byte unsigned integer
diff --git a/libpng.3 b/libpng.3
index 3f831044a..457f3c168 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "December 29, 2016"
+.TH LIBPNG 3 "December 30, 2016"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.28
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.29beta01
.SH SYNOPSIS
\fB
#include <png.h>\fP
@@ -496,7 +496,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
Libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.28 - December 29, 2016
+ libpng version 1.5.29beta01 - December 30, 2016
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -507,7 +507,7 @@ Libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.28 - December 29, 2016
+ libpng versions 0.97, January 1998, through 1.5.29beta01 - December 30, 2016
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -5012,7 +5012,7 @@ Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.28 are Y2K compliant. It is my belief that earlier
+upward through 1.5.29beta01 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -5167,7 +5167,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.5.28 - December 29, 2016:
+Libpng version 1.5.29beta01 - December 30, 2016:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -5192,8 +5192,8 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000, through 1.5.28, December 29, 2016, are
-Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
+libpng versions 1.0.7, July 1, 2000, through 1.5.29beta01, December 30, 2016, are
+Copyright (c) 2000-2002, 2004, 2006-2017 Glenn Randers-Pehrson, are
derived from libpng-1.0.6, and are distributed according to the same
disclaimer and license as libpng-1.0.6 with the following individuals
added to the list of Contributing Authors:
@@ -5309,7 +5309,7 @@ files "pngbar.png" and "pngbar.jpg (88x31) and "pngnow.png" (98x31).
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-December 29, 2016
+December 30, 2016
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index ea586059f..c0965fdf3 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "December 29, 2016"
+.TH LIBPNGPF 3 "December 30, 2016"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.28
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.29beta01
(private functions)
.SH SYNOPSIS
\fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index 7229e1b8e..6e786e870 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "December 29, 2016"
+.TH PNG 5 "December 30, 2016"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 26c455640..460bfe9e5 100644
--- a/png.c
+++ b/png.c
@@ -1,8 +1,8 @@
/* png.c - location for general purpose libpng functions
*
- * Last changed in libpng 1.5.28 [December 29, 2016]
- * Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
+ * Last changed in libpng 1.5.29 [(PENDING RELEASE)]
+ * Copyright (c) 1998-2002,2004,2006-2017 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_28 Your_png_h_is_not_version_1_5_28;
+typedef png_libpng_version_1_5_29beta01 Your_png_h_is_not_version_1_5_29beta01;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -656,15 +656,15 @@ png_get_copyright(png_const_structp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.5.28 - December 29, 2016" PNG_STRING_NEWLINE \
- "Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson" \
+ "libpng version 1.5.29beta01 - December 30, 2016" PNG_STRING_NEWLINE \
+ "Copyright (c) 1998-2002,2004,2006-2017 Glenn Randers-Pehrson" \
PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.5.28 - December 29, 2016\
- Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson\
+ return "libpng version 1.5.29beta01 - December 30, 2016\
+ Copyright (c) 1998-2002,2004,2006-2017 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
# endif
diff --git a/pngconf.h b/pngconf.h
index 9f1d9069a..e1ccf6062 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.5.28, December 29, 2016
+ * libpng version 1.5.29beta01, December 30, 2016
*
* Copyright (c) 1998-2002,2004,2006-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index 2dda87ac1..758309c92 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -2083,4 +2083,4 @@ main(void)
#endif
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_28 Your_png_h_is_not_version_1_5_28;
+typedef png_libpng_version_1_5_29beta01 Your_png_h_is_not_version_1_5_29beta01;
diff --git a/projects/vstudio/README.txt b/projects/vstudio/README.txt
index 5d85e968c..79a3241a7 100644
--- a/projects/vstudio/README.txt
+++ b/projects/vstudio/README.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.5.28 - December 29, 2016
+libpng version 1.5.29beta01 - December 30, 2016
Copyright (c) 2010,2013,2016 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index b7c605c9d..679f50e84 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.5.28 - December 29, 2016
+ * libpng version 1.5.29beta01 - December 30, 2016
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 657317a6d..0a2f3e699 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
-Makefiles for libpng version 1.5.28 - December 29, 2016
+Makefiles for libpng version 1.5.29beta01 - December 30, 2016
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng15.so.15.1.5.28)
+ (gcc, creates libpng15.so.15.1.5.29beta01)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -34,12 +34,12 @@ pnglibconf.h.prebuilt => Stores configuration settings
makefile.os2 => OS/2 Makefile (gcc and emx, requires libpng.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng15.so.15.1.5.28)
+ creates libpng15.so.15.1.5.29beta01)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng15.so.15.1.5.28)
+ creates libpng15.so.15.1.5.29beta01)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng15.so.15.1.5.28)
+ creates libpng15.so.15.1.5.29beta01)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/def.c b/scripts/def.c
index c2543e1d4..3514f5cc4 100644
--- a/scripts/def.c
+++ b/scripts/def.c
@@ -21,7 +21,7 @@ PNG_DFN "OS2 DESCRIPTION "PNG image compression library""
PNG_DFN "OS2 CODE PRELOAD MOVEABLE DISCARDABLE"
PNG_DFN ""
PNG_DFN "EXPORTS"
-PNG_DFN ";Version 1.5.28"
+PNG_DFN ";Version 1.5.29beta01"
#define PNG_EXPORTA(ordinal, type, name, args, attributes)\
PNG_DFN "@" SYMBOL_PREFIX "@@" name "@"
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 2672bf3b2..926fc3e1f 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.5.28
+version=1.5.29beta01
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 0d7284229..bbae04b35 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng15
Name: libpng
Description: Loads and saves PNG files
-Version: 1.5.28
+Version: 1.5.29beta01
Libs: -L${libdir} -lpng15
Cflags: -I${includedir}
diff --git a/scripts/makefile.cegcc b/scripts/makefile.cegcc
index 1a41b21fc..2845ccabc 100644
--- a/scripts/makefile.cegcc
+++ b/scripts/makefile.cegcc
@@ -23,7 +23,7 @@
VERMAJ = 1
VERMIN = 5
-VERMIC = 28
+VERMIC = 29
VER = $(VERMAJ).$(VERMIN).$(VERMIC)
NAME = libpng
PACKAGE = $(NAME)-$(VER)
diff --git a/scripts/makefile.linux b/scripts/makefile.linux
index 3647f0561..3df26d9e6 100644
--- a/scripts/makefile.linux
+++ b/scripts/makefile.linux
@@ -10,7 +10,7 @@
# Library name:
LIBNAME = libpng15
PNGMAJ = 15
-RELEASE = 28
+RELEASE = 29
# Shared library names:
LIBSO=$(LIBNAME).so
diff --git a/scripts/makefile.msys b/scripts/makefile.msys
index 22707b83d..2111b7489 100644
--- a/scripts/makefile.msys
+++ b/scripts/makefile.msys
@@ -18,7 +18,7 @@ exec_prefix=$(prefix)
# Library name:
LIBNAME = libpng15
PNGMAJ = 15
-RELEASE = 28
+RELEASE = 29
# Shared library names:
LIBSO=$(LIBNAME).dll
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 43661772a..c82497036 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng15
LIB= png15
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.5.28
+SHLIB_MINOR= 1.5.29beta01
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index ffe7b10d4..51e8a6e32 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 15
-SHLIB_MINOR= 1.5.28
+SHLIB_MINOR= 1.5.29beta01
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 486208471..5daa1ffe0 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 15
-SHLIB_MINOR= 1.5.28
+SHLIB_MINOR= 1.5.29beta01
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 3c5f373f7..8b7745346 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -1,7 +1,7 @@
-/* 1.5.28 STANDARD API DEFINITION */
+/* 1.5.29beta01 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* libpng version 1.5.28 - December 29, 2016 */
+/* libpng version 1.5.29beta01 - December 30, 2016 */
/* Copyright (c) 2011-2015 Glenn Randers-Pehrson */
diff --git a/scripts/symbols.def b/scripts/symbols.def
index 0ec682c97..e182f6164 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -1,4 +1,4 @@
-;Version 1.5.28
+;Version 1.5.29beta01
;--------------------------------------------------------------
; LIBPNG symbol list as a Win32 DEF file
; Contains all the symbols that can be exported from libpng
diff --git a/png.h b/png.h
index 16047f1db..afeaf1137 100644
--- a/png.h
+++ b/png.h
@@ -1,9 +1,9 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.28, December 29, 2016
*
- * Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
+ * Copyright (c) 1998-2002,2004,2006-2017 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
@@ -12,7 +12,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.28, December 29, 2016:
* Glenn Randers-Pehrson.
* See also "Contributing Authors", below.
*/
@@ -25,8 +25,8 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.0.7, July 1, 2000, through 1.5.28, December 29, 2016, are
* Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
* derived from libpng-1.0.6, and are distributed according to the same
* disclaimer and license as libpng-1.0.6 with the following individuals
* added to the list of Contributing Authors:
@@ -228,13 +228,13 @@
* Y2K compliance in libpng:
* =========================
*
- * December 29, 2016
+ * December 30, 2016
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.28 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -295,9 +295,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.28"
+#define PNG_LIBPNG_VER_STRING "1.5.29beta01"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.28 - December 29, 2016\n"
+ " libpng version 1.5.29beta01 - December 30, 2016\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -305,13 +305,13 @@
/* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
#define PNG_LIBPNG_VER_MAJOR 1
#define PNG_LIBPNG_VER_MINOR 5
-#define PNG_LIBPNG_VER_RELEASE 28
+#define PNG_LIBPNG_VER_RELEASE 29
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 0
+#define PNG_LIBPNG_VER_BUILD 01
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -328,7 +328,7 @@
#define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
PNG_LIBPNG_BUILD_PRIVATE */
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_STABLE
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_BETA
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -336,7 +336,7 @@
* version 1.0.0 was mis-numbered 100 instead of 10000). From
* version 1.0.1 it's xxyyzz, where x=major, y=minor, z=release
*/
-#define PNG_LIBPNG_VER 10528 /* 1.5.28 */
+#define PNG_LIBPNG_VER 10529 /* 1.5.29 */
/* Library configuration: these options cannot be changed after
* the library has been built.
@@ -458,7 +458,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_28;
+typedef char* png_libpng_version_1_5_29beta01;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,9 +1,9 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.28, December 29, 2016
+ * libpng version 1.5.29beta01, December 30, 2016
*
@@ -12,7 +12,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.28, December 29, 2016:
+ * libpng versions 0.97, January 1998, through 1.5.29beta01, December 30, 2016:
* Glenn Randers-Pehrson.
* See also "Contributing Authors", below.
@@ -25,8 +25,8 @@
* This code is released under the libpng license.
*
- * libpng versions 1.0.7, July 1, 2000, through 1.5.28, December 29, 2016, are
- * Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
+ * libpng versions 1.0.7, July 1, 2000, through 1.5.29beta01, December 30, 2016, are
+ * Copyright (c) 2000-2002, 2004, 2006-2017 Glenn Randers-Pehrson, are
* derived from libpng-1.0.6, and are distributed according to the same
* disclaimer and license as libpng-1.0.6 with the following individuals
@@ -228,13 +228,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.28 are Y2K compliant. It is my belief that
+ * upward through 1.5.29beta01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*